@@ -1,6 +1,8 @@
 # Author: David Burns
 # License: BSD
 
+import pytest
+import warnings
 import numpy as np
 import pandas as pd
 from sklearn.linear_model import Ridge
@@ -30,6 +32,7 @@ def transformation_test(clf, X, y):
     assert len(Xtr1) == len(ytr1)
 
 
+@pytest.mark.filterwarnings("ignore:deprecated, use Segment class")
 def test_pipe_transformation():
     # SegmentX transform pipe
     pipe = Pype([('seg', SegmentX()),
@@ -105,15 +108,19 @@ def classifier_test(clf, X, y):
     assert pp.shape[0] == len(yp)
     assert pp.shape[1] == len(yv)
     score = clf.score(X, y)
-    assert score <= 1.0 and score >= 0.0
+    assert 1.0 >= score >= 0.0
+
+    ys = clf.predict_as_series(X)
+    assert len(X) == len(ys)
 
     if clf._get_segmenter():
-        s = clf.predict_segmented_series(X, categorical_target=True)
+        s = clf.predict_unsegmented(X, categorical_target=True)
         for i in np.arange(len(X)):
             assert len(X[i]) == len(s[i])
             assert np.all(np.isin(np.unique(s[i]), yv))
 
 
+@pytest.mark.filterwarnings("ignore:deprecated, use Segment class")
 def test_pipe_classification():
     # no context data, single time series
     X = [np.random.rand(1000, 10)]
@@ -171,16 +178,20 @@ def regression_test(clf, X, y):
     assert len(ytr) == len(yp2)
     assert np.all(yp == yp2)
     score = clf.score(X, y)
-    assert score <= 1.0 and score >= 0.0
+    assert 1.0 >= score >= 0.0
+
+    ys = clf.predict_as_series(X)
+    assert len(X) == len(ys)
 
     if clf._get_segmenter():
-        s = clf.predict_segmented_series(X, categorical_target=False)
+        s = clf.predict_unsegmented(X, categorical_target=False)
         for i in np.arange(len(X)):
             assert len(X[i]) == len(s[i])
             assert np.max(yp) >= np.max(s[i])
             assert np.min(yp) <= np.min(s[i])
 
 
+@pytest.mark.filterwarnings("ignore:deprecated, use Segment class")
 def test_pipe_regression():
     # no context data, single time series
     X = [np.random.rand(1000, 10)]
@@ -238,7 +249,7 @@ def forecast_test(clf, X, y):
     assert len(ytr) == len(yp2)
     assert np.all(yp == yp2)
     score = clf.score(X, y)
-    assert score <= 1.0 and score >= 0.0
+    assert 1.0 >= score >= 0.0
 
 
 def test_pipe_forecast():
